summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rwxr-xr-xtasks/docs.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/tasks/docs.rb b/tasks/docs.rb
index dc5c747857..157c2a4655 100755
--- a/tasks/docs.rb
+++ b/tasks/docs.rb
@@ -283,8 +283,8 @@ namespace :docs_site do
# sort the hash so we can generate the menu weights later
resources = Hash[resources.sort]
- # weight is used to build the menu order. We start at 10 and increment by 10 each time
- @weight = 10
+ # weight is used to build the menu order. We start at 70 and increment by 10 each time
+ @weight = 70
resources.each do |resource, data|
# skip some resources we don't directly document